@@ -18,4 +18,9 @@ ODCCM_DEVICE_PASSWORD_FLAG_SET               = 1
 ODCCM_DEVICE_PASSWORD_FLAG_PROVIDE           = 2
 ODCCM_DEVICE_PASSWORD_FLAG_PROVIDE_ON_DEVICE = 4
 
+SYNCE_DEVICE_PASSWORD_FLAG_UNSET             = "unset"
+SYNCE_DEVICE_PASSWORD_FLAG_PROVIDE           = "provide"
+SYNCE_DEVICE_PASSWORD_FLAG_PROVIDE_ON_DEVICE = "provide-on-device"
+SYNCE_DEVICE_PASSWORD_FLAG_CHECKING          = "checking"
+SYNCE_DEVICE_PASSWORD_FLAG_UNLOCKED          = "unlocked"
 
