@@ -242,6 +242,12 @@ class GuiDbus(dbus.service.Object):
 
 
     def handleDeviceAuthorized(self):
+        #print QtGui.QApplication.activeModalWidget()
+        if QtGui.QApplication.activeModalWidget() is not None:
+            QtGui.QApplication.activeModalWidget().close()
+
+
+
         self.mainwindow.tabWidget.setEnabled(True)
         self.mainwindow.labelDeviceIsLocked.setVisible(False)
         self.mainwindow.toolButtonDeviceIsLocked.setVisible(False)
@@ -284,6 +290,7 @@ class GuiDbus(dbus.service.Object):
         self.mainwindow.array_async_status_pships_label[1].setText( "" )
         self.mainwindow.array_async_status_pships_label[2].setText( "" )
 
+        self.mainwindow.batteryStatus.setValue( 0 )
 
         self.mainwindow.modelPartnerships.clear()
         self.mainwindow.listInstalledPrograms.clear()
